@@ -6,6 +6,7 @@ package Verilog::Netlist::Module;
 
 use Verilog::Netlist;
 use Verilog::Netlist::ContAssign;
+use Verilog::Netlist::Defparam;
 use Verilog::Netlist::Port;
 use Verilog::Netlist::Net;
 use Verilog::Netlist::Cell;
@@ -16,7 +17,7 @@ use strict;
 @ISA = qw(Verilog::Netlist::Module::Struct
 	Verilog::Netlist::Subclass);
 
-$VERSION = '3.241';
+$VERSION = '3.250';
 
 structs('new',
 	'Verilog::Netlist::Module::Struct'
@@ -215,6 +216,21 @@ sub new_contassign {
     return $newref;
 }
 
+sub new_defparam {
+    my $self = shift;
+    my %params = @_; # name=>, filename=>, lineno=>, keyword=> etc
+    # Create a new statement under this module
+    if (!defined $params{name} || $params{name} eq '') {
+	# Blank instance name; invent a new one; use the next instance number in this module t$
+	$params{name} = '__unnamed_statement_' . ((scalar keys %{$self->_statements}) + 1);
+    }
+    # Create a new object; pass the potentially modified options
+    my $newref = new Verilog::Netlist::Defparam(%params, module=>$self,);
+    # Add the new object to the hash of statements in this module
+    $self->_statements($params{name}, $newref);
+    return $newref;
+}
+
 sub level {
     my $self = shift;
     my $level = $self->_level;
