@@ -14,11 +14,12 @@ use base qw(Verilog::Parser);
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.241';
+$VERSION = '3.250';
 
 our @_Callback_Names = qw(
   attribute
   contassign
+  defparam
   endcell
   endinterface
   endmodport
@@ -100,6 +101,12 @@ sub contassign {
     my $rhs = shift;
 }
 
+sub defparam {
+    my $self = shift;
+    my $lhs = shift;
+    my $rhs = shift;
+}
+
 sub endcell {
     my $self = shift;
 }
@@ -288,6 +295,11 @@ right hand part of the assignment.  Note that "wire" initializations are
 not considered assignments; those are received via the var callback's value
 parameter.
 
+=item $self->defparam ( $token, $lhs, $rhs )
+
+This method is called at a "defparam" keyword, with the left and right hand
+part of the assignment.
+
 =item $self->endcell ( $token )
 
 This method is called at the end of defining a cell. It is useful for
